This is an automated email from the ASF dual-hosted git repository.

johnbodley pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/superset.git


The following commit(s) were added to refs/heads/master by this push:
     new 1ccbc655eb fix: Update migration logic in #27119 (#28422)
1ccbc655eb is described below

commit 1ccbc655ebe1cee696726b716ec7a7731e8578f7
Author: John Bodley <[email protected]>
AuthorDate: Mon May 13 11:55:59 2024 -0700

    fix: Update migration logic in #27119 (#28422)
---
 superset/migrations/shared/utils.py                | 33 +++++++++++----
 ...14-43_17fcea065655_change_text_to_mediumtext.py | 48 ++++++++++++++--------
 superset/models/sql_lab.py                         | 14 +++++--
 superset/utils/core.py                             |  6 ++-
 4 files changed, 71 insertions(+), 30 deletions(-)

diff --git 
a/superset/migrations/versions/2024-02-14_14-43_17fcea065655_change_text_to_mediumtext.py
 
b/superset/migrations/versions/2024-02-14_14-43_17fcea065655_change_text_to_mediumtext.py
index 3ba126d24e..da15245a07 100644
--- 
a/superset/migrations/versions/2024-02-14_14-43_17fcea065655_change_text_to_mediumtext.py
+++ 
b/superset/migrations/versions/2024-02-14_14-43_17fcea065655_change_text_to_mediumtext.py
@@ -28,8 +28,10 @@ down_revision = "87d38ad83218"
 
 import sqlalchemy as sa  # noqa: E402
 from alembic import op  # noqa: E402
+from sqlalchemy.dialects.mysql import MEDIUMTEXT, TEXT  # noqa: E402
 from sqlalchemy.dialects.mysql.base import MySQLDialect  # noqa: E402
 
+from superset.migrations.shared.utils import get_table_column  # noqa: E402
 from superset.utils.core import MediumText  # noqa: E402
 
 TABLE_COLUMNS = [
@@ -38,8 +40,6 @@ TABLE_COLUMNS = [
     "dashboards.css",
     "keyvalue.value",
     "query.extra_json",
-    "query.executed_sql",
-    "query.select_sql",
     "report_execution_log.value_row_json",
     "report_recipient.recipient_config_json",
     "report_schedule.sql",
@@ -65,23 +65,35 @@ NOT_NULL_COLUMNS = ["keyvalue.value", 
"row_level_security_filters.clause"]
 
 def upgrade():
     if isinstance(op.get_bind().dialect, MySQLDialect):
-        for column in TABLE_COLUMNS:
-            with op.batch_alter_table(column.split(".")[0]) as batch_op:
-                batch_op.alter_column(
-                    column.split(".")[1],
-                    existing_type=sa.Text(),
-                    type_=MediumText(),
-                    existing_nullable=column not in NOT_NULL_COLUMNS,
-                )
+        for item in TABLE_COLUMNS:
+            table_name, column_name = item.split(".")
+
+            if (column := get_table_column(table_name, column_name)) and 
isinstance(
+                column["type"],
+                TEXT,
+            ):
+                with op.batch_alter_table(table_name) as batch_op:
+                    batch_op.alter_column(
+                        column_name,
+                        existing_type=sa.Text(),
+                        type_=MediumText(),
+                        existing_nullable=item not in NOT_NULL_COLUMNS,
+                    )
 
 
 def downgrade():
     if isinstance(op.get_bind().dialect, MySQLDialect):
-        for column in TABLE_COLUMNS:
-            with op.batch_alter_table(column.split(".")[0]) as batch_op:
-                batch_op.alter_column(
-                    column.split(".")[1],
-                    existing_type=MediumText(),
-                    type_=sa.Text(),
-                    existing_nullable=column not in NOT_NULL_COLUMNS,
-                )
+        for item in TABLE_COLUMNS:
+            table_name, column_name = item.split(".")
+
+            if (column := get_table_column(table_name, column_name)) and 
isinstance(
+                column["type"],
+                MEDIUMTEXT,
+            ):
+                with op.batch_alter_table(table_name) as batch_op:
+                    batch_op.alter_column(
+                        column_name,
+                        existing_type=MediumText(),
+                        type_=sa.Text(),
+                        existing_nullable=item not in NOT_NULL_COLUMNS,
+                    )
diff --git a/superset/models/sql_lab.py b/superset/models/sql_lab.py
index 41647ea43b..4e948b58e9 100644
--- a/superset/models/sql_lab.py
+++ b/superset/models/sql_lab.py
@@ -59,7 +59,13 @@ from superset.models.helpers import (
 )
 from superset.sql_parse import CtasMethod, extract_tables_from_jinja_sql, Table
 from superset.sqllab.limiting_factor import LimitingFactor
-from superset.utils.core import get_column_name, MediumText, QueryStatus, 
user_label
+from superset.utils.core import (
+    get_column_name,
+    LongText,
+    MediumText,
+    QueryStatus,
+    user_label,
+)
 
 if TYPE_CHECKING:
     from superset.connectors.sqla.models import TableColumn
@@ -110,11 +116,11 @@ class Query(
     sql_editor_id = Column(String(256), index=True)
     schema = Column(String(256))
     catalog = Column(String(256), nullable=True, default=None)
-    sql = Column(MediumText())
+    sql = Column(LongText())
     # Query to retrieve the results,
     # used only in case of select_as_cta_used is true.
-    select_sql = Column(MediumText())
-    executed_sql = Column(MediumText())
+    select_sql = Column(LongText())
+    executed_sql = Column(LongText())
     # Could be configured in the superset config.
     limit = Column(Integer)
     limiting_factor = Column(
diff --git a/superset/utils/core.py b/superset/utils/core.py
index 6b44fda4e4..e0eef6791d 100644
--- a/superset/utils/core.py
+++ b/superset/utils/core.py
@@ -70,7 +70,7 @@ from markupsafe import Markup
 from pandas.api.types import infer_dtype
 from pandas.core.dtypes.common import is_numeric_dtype
 from sqlalchemy import event, exc, inspect, select, Text
-from sqlalchemy.dialects.mysql import MEDIUMTEXT
+from sqlalchemy.dialects.mysql import LONGTEXT, MEDIUMTEXT
 from sqlalchemy.engine import Connection, Engine
 from sqlalchemy.engine.reflection import Inspector
 from sqlalchemy.sql.type_api import Variant
@@ -1497,6 +1497,10 @@ def MediumText() -> Variant:  # 
pylint:disable=invalid-name
     return Text().with_variant(MEDIUMTEXT(), "mysql")
 
 
+def LongText() -> Variant:  # pylint:disable=invalid-name
+    return Text().with_variant(LONGTEXT(), "mysql")
+
+
 def shortid() -> str:
     return f"{uuid.uuid4()}"[-12:]
 

Reply via email to
diff --git a/superset/migrations/shared/utils.py 
b/superset/migrations/shared/utils.py
index db20140db9..208d839bc1 100644
--- a/superset/migrations/shared/utils.py
+++ b/superset/migrations/shared/utils.py
@@ -34,21 +34,40 @@ logger = logging.getLogger(__name__)
 DEFAULT_BATCH_SIZE = int(os.environ.get("BATCH_SIZE", 1000))
 
 
-def table_has_column(table: str, column: str) -> bool:
+def get_table_column(
+    table_name: str,
+    column_name: str,
+) -> Optional[list[dict[str, Any]]]:
     """
-    Checks if a column exists in a given table.
+    Get the specified column.
 
     :param table: A table name
     :param column: A column name
     :returns: True iff the column exists in the table
     """
 
     insp = inspect(op.get_context().bind)
 
     try:
-        return any(col["name"] == column for col in insp.get_columns(table))
+        for column in insp.get_columns(table_name):
+            if column["name"] == column_name:
+                return column
     except NoSuchTableError:
-        return False
+        pass
+
+    return None
+
+
+def table_has_column(table_name: str, column_name: str) -> bool:
+    """
+    Checks if a column exists in a given table.
+
+    :param table_name: A table name
+    :param column_name: A column name
+    :returns: True iff the column exists in the table
+    """
+
+    return bool(get_table_column(table_name, column_name))
 
 
 def table_has_index(table: str, index: str) -> bool:
@@ -34,21 +34,40 @@ logger = logging.getLogger(__name__)
 
-    :param table: A table name
-    :param column: A column name
-    :returns: True iff the column exists in the table
+    :param table_name: The Table name
+    :param column_name: The column name
+    :returns: The column
     """
 